==> jc-1.4.0.tar.gz: soot/jimple/parser/node/X2PArrayBrackets.h <==
// public final class soot.jimple.parser.node.X2PArrayBrackets

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 73de4e43969ada95 soot_jimple_parser_node_Node
// @dep_class 92210315d08ef04b soot_jimple_parser_node_X2PArrayBrackets
// @dep_class efc8156a707ed4b3 soot_jimple_parser_node_XPArrayBrackets

// header file dependencies
// @dep_header soot_jimple_parser_node_XPArrayBrackets

#include "soot/jimple/parser/node/XPArrayBrackets.h"

#ifndef _JC_soot_jimple_parser_node_X2PArrayBrackets_H_
#define _JC_soot_jimple_parser_node_X2PArrayBrackets_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_jimple_parser_node_Node$object;
struct _jc_soot_jimple_parser_node_PArrayBrackets$object;
struct _jc_soot_jimple_parser_node_Switch$object;

// Typedefs
typedef struct _jc_soot_jimple_parser_node_X2PArrayBrackets$sub_refs	_jc_soot_jimple_parser_node_X2PArrayBrackets$sub_refs;
typedef struct _jc_soot_jimple_parser_node_X2PArrayBrackets$sub_nonrefs	_jc_soot_jimple_parser_node_X2PArrayBrackets$sub_nonrefs;
typedef struct _jc_soot_jimple_parser_node_X2PArrayBrackets$refs	_jc_soot_jimple_parser_node_X2PArrayBrackets$refs;
typedef struct _jc_soot_jimple_parser_node_X2PArrayBrackets$nonrefs	_jc_soot_jimple_parser_node_X2PArrayBrackets$nonrefs;
typedef struct _jc_soot_jimple_parser_node_X2PArrayBrackets$object	_jc_soot_jimple_parser_node_X2PArrayBrackets$object;

typedef const struct _jc_soot_jimple_parser_node_X2PArrayBrackets$vmethods	_jc_soot_jimple_parser_node_X2PArrayBrackets$vmethods;
typedef const struct _jc_soot_jimple_parser_node_X2PArrayBrackets$vtable	_jc_soot_jimple_parser_node_X2PArrayBrackets$vtable;
typedef const struct _jc_soot_jimple_parser_node_X2PArrayBrackets$vtype	_jc_soot_jimple_parser_node_X2PArrayBrackets$vtype;

// Constructors
extern void _jc_soot_jimple_parser_node_X2PArrayBrackets$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_parser_node_X2PArrayBrackets$object *);
extern void _jc_soot_jimple_parser_node_X2PArrayBrackets$method$_init$b163e967ef1c6b99(_jc_env *, struct _jc_soot_jimple_parser_node_X2PArrayBrackets$object *, struct _jc_soot_jimple_parser_node_PArrayBrackets$object *);

// Virtual methods
extern void _jc_soot_jimple_parser_node_X2PArrayBrackets$method$apply$7d8f74ce7309b216(_jc_env *, struct _jc_soot_jimple_parser_node_X2PArrayBrackets$object *, struct _jc_object *);
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_parser_node_X2PArrayBrackets$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_jimple_parser_node_X2PArrayBrackets$object *);
extern struct _jc_soot_jimple_parser_node_PArrayBrackets$object *_jc_soot_jimple_parser_node_X2PArrayBrackets$method$getPArrayBrackets$9bedb2a5d8b2830c(_jc_env *, struct _jc_soot_jimple_parser_node_X2PArrayBrackets$object *);
extern void _jc_soot_jimple_parser_node_X2PArrayBrackets$method$removeChild$f5fdaab456b88f05(_jc_env *, struct _jc_soot_jimple_parser_node_X2PArrayBrackets$object *, struct _jc_soot_jimple_parser_node_Node$object *);
extern void _jc_soot_jimple_parser_node_X2PArrayBrackets$method$replaceChild$f0df61b776b15826(_jc_env *, struct _jc_soot_jimple_parser_node_X2PArrayBrackets$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *);
extern void _jc_soot_jimple_parser_node_X2PArrayBrackets$method$setPArrayBrackets$3f585f4511d9e8d8(_jc_env *, struct _jc_soot_jimple_parser_node_X2PArrayBrackets$object *, struct _jc_soot_jimple_parser_node_PArrayBrackets$object *);
extern struct _jc_java_lang_String$object *_jc_soot_jimple_parser_node_X2PArrayBrackets$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_parser_node_X2PArrayBrackets$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_parser_node_X2PArrayBrackets$method_info$apply$7d8f74ce7309b216;
extern _jc_method _jc_soot_jimple_parser_node_X2PArrayBrackets$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_jimple_parser_node_X2PArrayBrackets$method_info$getPArrayBrackets$9bedb2a5d8b2830c;
extern _jc_method _jc_soot_jimple_parser_node_X2PArrayBrackets$method_info$removeChild$f5fdaab456b88f05;
extern _jc_method _jc_soot_jimple_parser_node_X2PArrayBrackets$method_info$replaceChild$f0df61b776b15826;
extern _jc_method _jc_soot_jimple_parser_node_X2PArrayBrackets$method_info$setPArrayBrackets$3f585f4511d9e8d8;
extern _jc_method _jc_soot_jimple_parser_node_X2PArrayBrackets$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_jimple_parser_node_X2PArrayBrackets$vmethods {
	void	(*apply$7d8f74ce7309b216)(_jc_env *, struct _jc_soot_jimple_parser_node_X2PArrayBrackets$object *, struct _jc_object *);
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_jimple_parser_node_X2PArrayBrackets$object *);
	struct _jc_soot_jimple_parser_node_PArrayBrackets$object	*(*getPArrayBrackets$9bedb2a5d8b2830c)(_jc_env *, struct _jc_soot_jimple_parser_node_X2PArrayBrackets$object *);
	void	(*removeChild$f5fdaab456b88f05)(_jc_env *, struct _jc_soot_jimple_parser_node_X2PArrayBrackets$object *, struct _jc_soot_jimple_parser_node_Node$object *);
	void	(*replaceChild$f0df61b776b15826)(_jc_env *, struct _jc_soot_jimple_parser_node_X2PArrayBrackets$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *);
	void	(*setPArrayBrackets$3f585f4511d9e8d8)(_jc_env *, struct _jc_soot_jimple_parser_node_X2PArrayBrackets$object *, struct _jc_soot_jimple_parser_node_PArrayBrackets$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_parser_node_X2PArrayBrackets$object *);
};

// Vtable
struct _jc_soot_jimple_parser_node_X2PArrayBrackets$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_parser_node_Node$vmethods	soot_jimple_parser_node_Node;
	_jc_soot_jimple_parser_node_XPArrayBrackets$vmethods	soot_jimple_parser_node_XPArrayBrackets;
	_jc_soot_jimple_parser_node_X2PArrayBrackets$vmethods	soot_jimple_parser_node_X2PArrayBrackets;
};

// Vtype
struct _jc_soot_jimple_parser_node_X2PArrayBrackets$vtype {
	_jc_type			type;
	_jc_soot_jimple_parser_node_X2PArrayBrackets$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_X2PArrayBrackets$sub_refs {
	struct _jc_soot_jimple_parser_node_PArrayBrackets$object	*__5fpArrayBrackets__5f;
};

// Reference instance fields (object)
struct _jc_soot_jimple_parser_node_X2PArrayBrackets$refs {
    _jc_soot_jimple_parser_node_X2PArrayBrackets$sub_refs	soot_jimple_parser_node_X2PArrayBrackets;
    _jc_soot_jimple_parser_node_XPArrayBrackets$sub_refs	soot_jimple_parser_node_XPArrayBrackets;
    _jc_soot_jimple_parser_node_Node$sub_refs	soot_jimple_parser_node_Node;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_X2PArrayBrackets$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_parser_node_X2PArrayBrackets$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_parser_node_Node$sub_nonrefs	soot_jimple_parser_node_Node;
    _jc_soot_jimple_parser_node_XPArrayBrackets$sub_nonrefs	soot_jimple_parser_node_XPArrayBrackets;
    _jc_soot_jimple_parser_node_X2PArrayBrackets$sub_nonrefs	soot_jimple_parser_node_X2PArrayBrackets;
};

// Object instance structure
struct _jc_soot_jimple_parser_node_X2PArrayBrackets$object {
	_jc_soot_jimple_parser_node_X2PArrayBrackets$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_parser_node_X2PArrayBrackets$vtype	*vtype;
	_jc_soot_jimple_parser_node_X2PArrayBrackets$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_parser_node_X2PArrayBrackets$vtype _jc_soot_jimple_parser_node_X2PArrayBrackets$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_parser_node_X2PArrayBrackets, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_parser_node_X2PArrayBrackets$class_object;

#endif	/* _JC_soot_jimple_parser_node_X2PArrayBrackets_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/parser/node/X2PArrayBrackets.h <==
// public final class soot.jimple.parser.node.X2PArrayBrackets

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 73de4e43969ada95 soot_jimple_parser_node_Node
// @dep_class 92210315d08ef04b soot_jimple_parser_node_X2PArrayBrackets
// @dep_class efc8156a707ed4b3 soot_jimple_parser_node_XPArrayBrackets

// header file dependencies
// @dep_header soot_jimple_parser_node_XPArrayBrackets

#include "soot/jimple/parser/node/XPArrayBrackets.h"

#ifndef _JC_soot_jimple_parser_node_X2PArrayBrackets_H_
#define _JC_soot_jimple_parser_node_X2PArrayBrackets_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_jimple_parser_node_Node$object;
struct _jc_soot_jimple_parser_node_PArrayBrackets$object;
struct _jc_soot_jimple_parser_node_Switch$object;

// Typedefs
typedef struct _jc_soot_jimple_parser_node_X2PArrayBrackets$sub_refs	_jc_soot_jimple_parser_node_X2PArrayBrackets$sub_refs;
typedef struct _jc_soot_jimple_parser_node_X2PArrayBrackets$sub_nonrefs	_jc_soot_jimple_parser_node_X2PArrayBrackets$sub_nonrefs;
typedef struct _jc_soot_jimple_parser_node_X2PArrayBrackets$refs	_jc_soot_jimple_parser_node_X2PArrayBrackets$refs;
typedef struct _jc_soot_jimple_parser_node_X2PArrayBrackets$nonrefs	_jc_soot_jimple_parser_node_X2PArrayBrackets$nonrefs;
typedef struct _jc_soot_jimple_parser_node_X2PArrayBrackets$object	_jc_soot_jimple_parser_node_X2PArrayBrackets$object;

typedef const struct _jc_soot_jimple_parser_node_X2PArrayBrackets$vmethods	_jc_soot_jimple_parser_node_X2PArrayBrackets$vmethods;
typedef const struct _jc_soot_jimple_parser_node_X2PArrayBrackets$vtable	_jc_soot_jimple_parser_node_X2PArrayBrackets$vtable;
typedef const struct _jc_soot_jimple_parser_node_X2PArrayBrackets$vtype	_jc_soot_jimple_parser_node_X2PArrayBrackets$vtype;

// Constructors
extern void _jc_soot_jimple_parser_node_X2PArrayBrackets$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_parser_node_X2PArrayBrackets$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_X2PArrayBrackets$method$_init$b163e967ef1c6b99(_jc_env *, struct _jc_soot_jimple_parser_node_X2PArrayBrackets$object *, struct _jc_soot_jimple_parser_node_PArrayBrackets$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_jimple_parser_node_X2PArrayBrackets$method$apply$7d8f74ce7309b216(_jc_env *, struct _jc_soot_jimple_parser_node_X2PArrayBrackets$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_parser_node_X2PArrayBrackets$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_jimple_parser_node_X2PArrayBrackets$object *) _JC_JCNI_ATTR;
extern struct _jc_soot_jimple_parser_node_PArrayBrackets$object *_jc_soot_jimple_parser_node_X2PArrayBrackets$method$getPArrayBrackets$9bedb2a5d8b2830c(_jc_env *, struct _jc_soot_jimple_parser_node_X2PArrayBrackets$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_X2PArrayBrackets$method$removeChild$f5fdaab456b88f05(_jc_env *, struct _jc_soot_jimple_parser_node_X2PArrayBrackets$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_X2PArrayBrackets$method$replaceChild$f0df61b776b15826(_jc_env *, struct _jc_soot_jimple_parser_node_X2PArrayBrackets$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_X2PArrayBrackets$method$setPArrayBrackets$3f585f4511d9e8d8(_jc_env *, struct _jc_soot_jimple_parser_node_X2PArrayBrackets$object *, struct _jc_soot_jimple_parser_node_PArrayBrackets$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_jimple_parser_node_X2PArrayBrackets$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_parser_node_X2PArrayBrackets$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_parser_node_X2PArrayBrackets$method_info$apply$7d8f74ce7309b216;
extern _jc_method _jc_soot_jimple_parser_node_X2PArrayBrackets$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_jimple_parser_node_X2PArrayBrackets$method_info$getPArrayBrackets$9bedb2a5d8b2830c;
extern _jc_method _jc_soot_jimple_parser_node_X2PArrayBrackets$method_info$removeChild$f5fdaab456b88f05;
extern _jc_method _jc_soot_jimple_parser_node_X2PArrayBrackets$method_info$replaceChild$f0df61b776b15826;
extern _jc_method _jc_soot_jimple_parser_node_X2PArrayBrackets$method_info$setPArrayBrackets$3f585f4511d9e8d8;
extern _jc_method _jc_soot_jimple_parser_node_X2PArrayBrackets$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_jimple_parser_node_X2PArrayBrackets$vmethods {
	void	(*apply$7d8f74ce7309b216)(_jc_env *, struct _jc_soot_jimple_parser_node_X2PArrayBrackets$object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_jimple_parser_node_X2PArrayBrackets$object *) _JC_JCNI_ATTR;
	struct _jc_soot_jimple_parser_node_PArrayBrackets$object	*(*getPArrayBrackets$9bedb2a5d8b2830c)(_jc_env *, struct _jc_soot_jimple_parser_node_X2PArrayBrackets$object *) _JC_JCNI_ATTR;
	void	(*removeChild$f5fdaab456b88f05)(_jc_env *, struct _jc_soot_jimple_parser_node_X2PArrayBrackets$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
	void	(*replaceChild$f0df61b776b15826)(_jc_env *, struct _jc_soot_jimple_parser_node_X2PArrayBrackets$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
	void	(*setPArrayBrackets$3f585f4511d9e8d8)(_jc_env *, struct _jc_soot_jimple_parser_node_X2PArrayBrackets$object *, struct _jc_soot_jimple_parser_node_PArrayBrackets$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_parser_node_X2PArrayBrackets$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_parser_node_X2PArrayBrackets$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_parser_node_Node$vmethods	soot_jimple_parser_node_Node;
	_jc_soot_jimple_parser_node_XPArrayBrackets$vmethods	soot_jimple_parser_node_XPArrayBrackets;
	_jc_soot_jimple_parser_node_X2PArrayBrackets$vmethods	soot_jimple_parser_node_X2PArrayBrackets;
};

// Vtype
struct _jc_soot_jimple_parser_node_X2PArrayBrackets$vtype {
	_jc_type			type;
	_jc_soot_jimple_parser_node_X2PArrayBrackets$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_X2PArrayBrackets$sub_refs {
	struct _jc_soot_jimple_parser_node_PArrayBrackets$object	*__5fpArrayBrackets__5f;
};

// Reference instance fields (object)
struct _jc_soot_jimple_parser_node_X2PArrayBrackets$refs {
    _jc_soot_jimple_parser_node_X2PArrayBrackets$sub_refs	soot_jimple_parser_node_X2PArrayBrackets;
    _jc_soot_jimple_parser_node_XPArrayBrackets$sub_refs	soot_jimple_parser_node_XPArrayBrackets;
    _jc_soot_jimple_parser_node_Node$sub_refs	soot_jimple_parser_node_Node;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_X2PArrayBrackets$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_parser_node_X2PArrayBrackets$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_parser_node_Node$sub_nonrefs	soot_jimple_parser_node_Node;
    _jc_soot_jimple_parser_node_XPArrayBrackets$sub_nonrefs	soot_jimple_parser_node_XPArrayBrackets;
    _jc_soot_jimple_parser_node_X2PArrayBrackets$sub_nonrefs	soot_jimple_parser_node_X2PArrayBrackets;
};

// Object instance structure
struct _jc_soot_jimple_parser_node_X2PArrayBrackets$object {
	_jc_soot_jimple_parser_node_X2PArrayBrackets$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_parser_node_X2PArrayBrackets$vtype	*vtype;
	_jc_soot_jimple_parser_node_X2PArrayBrackets$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_parser_node_X2PArrayBrackets$vtype _jc_soot_jimple_parser_node_X2PArrayBrackets$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_parser_node_X2PArrayBrackets, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_parser_node_X2PArrayBrackets$class_object;

#endif	/* _JC_soot_jimple_parser_node_X2PArrayBrackets_H_ */
